"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var emscripten_wasm_loader_1 = require("emscripten-wasm-loader");
var hunspellLoader_1 = require("./hunspellLoader");
var logger_1 = require("./util/logger");
/**
 * Load, initialize wasm binary to use actual hunspell wasm instances.
 *
 * @param [InitOptions] Options to initialize hunspell wasm binary.
 * @param {number} [InitOptions.timeout] - timeout to wait wasm binary compilation & load.
 * @param {string | object} [InitOptions.locateBinary] - custom resolution logic for wasm binary. (not supported)
 * @param {ENVIRONMENT} [InitOptions.environment] For overriding running environment
 * It could be either remote endpoint url, or loader-returned object for bundler. Check examples/browser_* for references.
 *
 * @returns {() => Promise<HunspellFactory>} Function to load module
 */
var loadModule = function (initOptions) {
    if (initOptions === void 0) { initOptions = {}; }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var runtime, environment, timeout, env, overriddenModule, moduleLoader;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    runtime = require("./lib/hunspell-asm");
                    environment = initOptions.environment, timeout = initOptions.timeout;
                    env = environment ? environment : emscripten_wasm_loader_1.isNode() ? emscripten_wasm_loader_1.ENVIRONMENT.NODE : emscripten_wasm_loader_1.ENVIRONMENT.WEB;
                    logger_1.log("loadModule: loading hunspell wasm binary", { initOptions: initOptions });
                    overriddenModule = { ENVIRONMENT: env };
                    return [4 /*yield*/, emscripten_wasm_loader_1.getModuleLoader(function (runtime) { return hunspellLoader_1.hunspellLoader(runtime, env); }, runtime, overriddenModule, { timeout: timeout })];
                case 1:
                    moduleLoader = _a.sent();
                    return [2 /*return*/, moduleLoader()];
            }
        });
    });
};
exports.loadModule = loadModule;
//# sourceMappingURL=loadModule.js.map