"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var emscripten_wasm_loader_1 = require("emscripten-wasm-loader");
var unixify = require("unixify");
var isMounted_1 = require("./isMounted");
var mkdirTree_1 = require("./mkdirTree");
var logger_1 = require("./util/logger");
/**
 * Creates a function to mount phsyical path into wasm internal memory filesystem
 * to allow wasm can access phsyical file directly.
 *
 * @param {FS} FS wasm module filesystem
 * @param {string} nodePathId root path in memory filesystem to mount given path under.
 * This prefix path is generated automatically each time wasm module is loaded.
 *
 * @return {(dirPath: string) => string} function to mount given phsical path under memory filesystem.
 */
/** @internal */
exports.mountDirectory = function (FS, nodePathId, environment) { return function (dirPath) {
    if (environment !== emscripten_wasm_loader_1.ENVIRONMENT.NODE) {
        throw new Error('Mounting physical directory is not supported other than node.js environment');
    }
    var path = require('path'); //tslint:disable-line:no-require-imports
    var mountedDirPath = unixify(path.join(nodePathId, unixify(path.resolve(dirPath))));
    if (isMounted_1.isMounted(FS, mountedDirPath, 'dir')) {
        logger_1.log("mountNodeFile: file is already mounted, return it");
    }
    else {
        mkdirTree_1.mkdirTree(FS, mountedDirPath);
        FS.mount(FS.filesystems.NODEFS, { root: path.resolve(dirPath) }, mountedDirPath);
    }
    return mountedDirPath;
}; };
//# sourceMappingURL=mountDirectory.js.map