var _this = this;
import * as tslib_1 from "tslib";
import { ENVIRONMENT, getModuleLoader, isNode } from 'emscripten-wasm-loader';
import { hunspellLoader } from './hunspellLoader';
import { log } from './util/logger';
/**
 * Load, initialize wasm binary to use actual hunspell wasm instances.
 *
 * @param [InitOptions] Options to initialize hunspell wasm binary.
 * @param {number} [InitOptions.timeout] - timeout to wait wasm binary compilation & load.
 * @param {string | object} [InitOptions.locateBinary] - custom resolution logic for wasm binary. (not supported)
 * @param {ENVIRONMENT} [InitOptions.environment] For overriding running environment
 * It could be either remote endpoint url, or loader-returned object for bundler. Check examples/browser_* for references.
 *
 * @returns {() => Promise<HunspellFactory>} Function to load module
 */
var loadModule = function (initOptions) {
    if (initOptions === void 0) { initOptions = {}; }
    return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var runtime, environment, timeout, env, overriddenModule, moduleLoader;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    runtime = require("./lib/hunspell-asm");
                    environment = initOptions.environment, timeout = initOptions.timeout;
                    env = environment ? environment : isNode() ? ENVIRONMENT.NODE : ENVIRONMENT.WEB;
                    log("loadModule: loading hunspell wasm binary", { initOptions: initOptions });
                    overriddenModule = { ENVIRONMENT: env };
                    return [4 /*yield*/, getModuleLoader(function (runtime) { return hunspellLoader(runtime, env); }, runtime, overriddenModule, { timeout: timeout })];
                case 1:
                    moduleLoader = _a.sent();
                    return [2 /*return*/, moduleLoader()];
            }
        });
    });
};
export { loadModule };
//# sourceMappingURL=loadModule.js.map